UserCredentialWatchos class

watchOS implementation of UserCredentialPlatform.

Inheritance
  • Object
  • PlatformInterface
  • UserCredentialWatchos

Constructors

UserCredentialWatchos({required FirebaseAuthPlatform auth, UserPlatform? user, AdditionalUserInfo? additionalUserInfo})
Creates the credential result of a sign-in operation.

Properties

additionalUserInfo → AdditionalUserInfo?
Returns additional information about the user, such as whether they are a newly created one.
finalinherited
auth → FirebaseAuthPlatform
The current FirebaseAuth instance.
finalinherited
credential → AuthCredential?
The users AuthCredential.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → UserPlatform?
Returns a UserPlatform containing additional information and user specific methods.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited